import numpy as np
import scipy.io
import csv
import pickle

# FUNCTION: loadtrackscsv
# INPUTS: string giving path to input CSV file
# OUTPUTS: list of 2xN_i arrays, where N_i is the number of position fixes in supplied track i

def loadtrackscsv(infile):
    
    sniffer = csv.Sniffer()
    csvfile = open(infile, 'rb')
    dialect = sniffer.sniff(csvfile.read(100))
    csvfile.seek(0)
    reader = csv.reader(csvfile, dialect)

    tracks = []
    for row in reader:
        this_track=[]
        this_track.append([float(col) for col in row])
        this_track.append([float(col) for col in reader.next()])
        tracks.append(np.array(this_track))
    
    return tracks

# END FUNCTION

# FUNCTION: loadtracksmat
# INPUTS:
# infile - string giving path to input MAT file
# variablename - string giving the name of the variable in which the tracks list is stored
# OUTPUTS: list of 2xN_i arrays, where N_i is the number of position fixes in supplied track i

def loadtracksmat(infile, variablename):
    
    mat = scipy.io.loadmat(infile)
    tracks = mat.pop(variablename, None)
    assert tracks != None, 'No variable exists with the supplied name'
    
    numtracks = len(tracks)
    
    tracks = [t[0] for t in tracks]
    
    return tracks

# END FUNCTION

# FUNCTION loadbootstrappickle
def loadbootstrappickle(infile):
    
    fin = open(infile, 'rb')
    d = pickle.load(fin)
    fin.close()
    
    noiselevels = d['noiselevels']
    bs = d['bs_transition_parameters']
    
    return noiselevels, bs

# END FUNCTION

# FUNCTION saverunprobstocsv
# INPUTS:
# run_probs - as computed using the HMM module
# outfile - full path to outgoing file
# b_overwrite - Boolean flag to enable overwriting the output file
#
# Saves the supplied run probabilities to a CSV file for later use.  CSV format is one line per track, with successive
# run probabilities given as a comma-separated list on that line.

def saverunprobstocsv(run_probs, outfile, b_overwrite=False):

    try:
        with open(outfile): pass
    except IOError:
        f = open(outfile, 'w')
    else:
        if b_overwrite:
            f = open(outfile, 'w')
        else:
            raise IOError('File already exists')

    csv_writer = csv.writer(f)
    csv_writer.writerows(run_probs)

    f.close()

# END FUNCTION
